
Avoid the use of default and predictable accounts
-------

**Description:**

Whenever default or predictable accounts are available on an application/server this could 
lead to an attacker compromising these services. Make sure al default and predictable 
accounts are disabled or deleted from the services. 


**Solution:**

Verify that all keys and passwords are replaceable, and are generated or 
replaced after installation time. 


	
